@@ -18,6 +18,132 @@ import warnings
 from tencentcloud.common.abstract_model import AbstractModel
 
 
+class CreateProductSecretRequest(AbstractModel):
+    """CreateProductSecret请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param SecretName: 凭据名称，同一region内不可重复，最长128字节，使用字母、数字或者 - _ 的组合，第一个字符必须为字母或者数字。
+        :type SecretName: str
+        :param UserNamePrefix: 用户账号名前缀，由用户自行指定，长度限定在8个字符以内，
+可选字符集包括：
+数字字符：[0, 9]，
+小写字符：[a, z]，
+大写字符：[A, Z]，
+特殊字符(全英文符号)：下划线(_)，
+前缀必须以大写或小写字母开头。
+        :type UserNamePrefix: str
+        :param ProductName: 凭据所绑定的云产品名称，如Mysql，可以通过DescribeSupportedProducts接口获取所支持的云产品名称。
+        :type ProductName: str
+        :param InstanceID: 云产品实例ID。
+        :type InstanceID: str
+        :param Domains: 账号的域名，IP形式，支持填入%。
+        :type Domains: list of str
+        :param PrivilegesList: 将凭据与云产品实例绑定时，需要授予的权限列表。
+        :type PrivilegesList: list of ProductPrivilegeUnit
+        :param Description: 描述信息，用于详细描述用途等，最大支持2048字节。
+        :type Description: str
+        :param KmsKeyId: 指定对凭据进行加密的KMS CMK。
+如果为空则表示使用Secrets Manager为您默认创建的CMK进行加密。
+您也可以指定在同region 下自行创建的KMS CMK进行加密。
+        :type KmsKeyId: str
+        :param Tags: 标签列表。
+        :type Tags: list of Tag
+        :param RotationBeginTime: 用户自定义的开始轮转时间，格式：2006-01-02 15:04:05。
+当EnableRotation为True时，此参数必填。
+        :type RotationBeginTime: str
+        :param EnableRotation: 是否开启轮转
+True -- 开启
+False -- 不开启
+如果不指定，默认为False。
+        :type EnableRotation: bool
+        :param RotationFrequency: 轮转周期，以天为单位，默认为1天。
+        :type RotationFrequency: int
+        """
+        self.SecretName = None
+        self.UserNamePrefix = None
+        self.ProductName = None
+        self.InstanceID = None
+        self.Domains = None
+        self.PrivilegesList = None
+        self.Description = None
+        self.KmsKeyId = None
+        self.Tags = None
+        self.RotationBeginTime = None
+        self.EnableRotation = None
+        self.RotationFrequency = None
+
+
+    def _deserialize(self, params):
+        self.SecretName = params.get("SecretName")
+        self.UserNamePrefix = params.get("UserNamePrefix")
+        self.ProductName = params.get("ProductName")
+        self.InstanceID = params.get("InstanceID")
+        self.Domains = params.get("Domains")
+        if params.get("PrivilegesList") is not None:
+            self.PrivilegesList = []
+            for item in params.get("PrivilegesList"):
+                obj = ProductPrivilegeUnit()
+                obj._deserialize(item)
+                self.PrivilegesList.append(obj)
+        self.Description = params.get("Description")
+        self.KmsKeyId = params.get("KmsKeyId")
+        if params.get("Tags") is not None:
+            self.Tags = []
+            for item in params.get("Tags"):
+                obj = Tag()
+                obj._deserialize(item)
+                self.Tags.append(obj)
+        self.RotationBeginTime = params.get("RotationBeginTime")
+        self.EnableRotation = params.get("EnableRotation")
+        self.RotationFrequency = params.get("RotationFrequency")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class CreateProductSecretResponse(AbstractModel):
+    """CreateProductSecret返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param SecretName: 创建的凭据名称。
+        :type SecretName: str
+        :param TagCode: 标签操作的返回码. 0: 成功；1: 内部错误；2: 业务处理错误。
+注意：此字段可能返回 null，表示取不到有效值。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TagCode: int
+        :param TagMsg: 标签操作的返回信息。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type TagMsg: str
+        :param FlowID: 创建云产品凭据异步任务ID号。
+        :type FlowID: int
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.SecretName = None
+        self.TagCode = None
+        self.TagMsg = None
+        self.FlowID = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.SecretName = params.get("SecretName")
+        self.TagCode = params.get("TagCode")
+        self.TagMsg = params.get("TagMsg")
+        self.FlowID = params.get("FlowID")
+        self.RequestId = params.get("RequestId")
+
+
 class CreateSecretRequest(AbstractModel):
     """CreateSecret请求参数结构体
 
@@ -212,6 +338,164 @@ class DeleteSecretVersionResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeAsyncRequestInfoRequest(AbstractModel):
+    """DescribeAsyncRequestInfo请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param FlowID: 异步任务ID号。
+        :type FlowID: int
+        """
+        self.FlowID = None
+
+
+    def _deserialize(self, params):
+        self.FlowID = params.get("FlowID")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeAsyncRequestInfoResponse(AbstractModel):
+    """DescribeAsyncRequestInfo返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param TaskStatus: 0:处理中，1:处理成功，2:处理失败
+        :type TaskStatus: int
+        :param Description: 任务描述信息。
+        :type Description: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.TaskStatus = None
+        self.Description = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.TaskStatus = params.get("TaskStatus")
+        self.Description = params.get("Description")
+        self.RequestId = params.get("RequestId")
+
+
+class DescribeRotationDetailRequest(AbstractModel):
+    """DescribeRotationDetail请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param SecretName: 指定需要获取凭据轮转详细信息的凭据名称。
+        :type SecretName: str
+        """
+        self.SecretName = None
+
+
+    def _deserialize(self, params):
+        self.SecretName = params.get("SecretName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeRotationDetailResponse(AbstractModel):
+    """DescribeRotationDetail返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param EnableRotation: 否允许轮转，True表示开启轮转，False表示禁止轮转。
+        :type EnableRotation: bool
+        :param Frequency: 轮转的频率，以天为单位，默认为1天。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Frequency: int
+        :param LatestRotateTime: 最近一次轮转的时间，显式可见的时间字符串，格式 2006-01-02 15:04:05。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type LatestRotateTime: str
+        :param NextRotateBeginTime: 下一次开始轮转的时间，显式可见的时间字符串，格式 2006-01-02 15:04:05。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type NextRotateBeginTime: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.EnableRotation = None
+        self.Frequency = None
+        self.LatestRotateTime = None
+        self.NextRotateBeginTime = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.EnableRotation = params.get("EnableRotation")
+        self.Frequency = params.get("Frequency")
+        self.LatestRotateTime = params.get("LatestRotateTime")
+        self.NextRotateBeginTime = params.get("NextRotateBeginTime")
+        self.RequestId = params.get("RequestId")
+
+
+class DescribeRotationHistoryRequest(AbstractModel):
+    """DescribeRotationHistory请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param SecretName: 指定需要获取凭据轮转历史的凭据名称。
+        :type SecretName: str
+        """
+        self.SecretName = None
+
+
+    def _deserialize(self, params):
+        self.SecretName = params.get("SecretName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeRotationHistoryResponse(AbstractModel):
+    """DescribeRotationHistory返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param VersionIDs: 版本号列表。
+        :type VersionIDs: list of str
+        :param TotalCount: 版本号个数，可以给用户展示的版本号个数上限为10个。
+        :type TotalCount: int
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.VersionIDs = None
+        self.TotalCount = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.VersionIDs = params.get("VersionIDs")
+        self.TotalCount = params.get("TotalCount")
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeSecretRequest(AbstractModel):
     """DescribeSecret请求参数结构体
 
@@ -251,12 +535,27 @@ class DescribeSecretResponse(AbstractModel):
         :type KmsKeyId: str
         :param CreateUin: 创建者UIN。
         :type CreateUin: int
-        :param Status: 凭据状态：Enabled、Disabled、PendingDelete
+        :param Status: 凭据状态：Enabled、Disabled、PendingDelete, Creating, Failed。
         :type Status: str
         :param DeleteTime: 删除日期，uinx 时间戳，非计划删除状态的凭据为0。
         :type DeleteTime: int
         :param CreateTime: 创建日期。
         :type CreateTime: int
+        :param SecretType: 0 --  用户自定义凭据类型；1 -- 云产品凭据类型。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SecretType: int
+        :param ProductName: 云产品名称。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ProductName: str
+        :param ResourceID: 云产品实例ID。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ResourceID: str
+        :param RotationStatus: 是否开启轮转：True -- 开启轮转；False -- 禁止轮转。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type RotationStatus: bool
+        :param RotationFrequency: 轮转周期，默认以天为单位。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type RotationFrequency: int
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -267,6 +566,11 @@ class DescribeSecretResponse(AbstractModel):
         self.Status = None
         self.DeleteTime = None
         self.CreateTime = None
+        self.SecretType = None
+        self.ProductName = None
+        self.ResourceID = None
+        self.RotationStatus = None
+        self.RotationFrequency = None
         self.RequestId = None
 
 
@@ -278,6 +582,42 @@ class DescribeSecretResponse(AbstractModel):
         self.Status = params.get("Status")
         self.DeleteTime = params.get("DeleteTime")
         self.CreateTime = params.get("CreateTime")
+        self.SecretType = params.get("SecretType")
+        self.ProductName = params.get("ProductName")
+        self.ResourceID = params.get("ResourceID")
+        self.RotationStatus = params.get("RotationStatus")
+        self.RotationFrequency = params.get("RotationFrequency")
+        self.RequestId = params.get("RequestId")
+
+
+class DescribeSupportedProductsRequest(AbstractModel):
+    """DescribeSupportedProducts请求参数结构体
+
+    """
+
+
+class DescribeSupportedProductsResponse(AbstractModel):
+    """DescribeSupportedProducts返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Products: 支持的产品列表。
+        :type Products: list of str
+        :param TotalCount: 支持的产品个数
+        :type TotalCount: int
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Products = None
+        self.TotalCount = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.Products = params.get("Products")
+        self.TotalCount = params.get("TotalCount")
         self.RequestId = params.get("RequestId")
 
 
@@ -408,6 +748,7 @@ class GetSecretValueRequest(AbstractModel):
         :param SecretName: 指定凭据的名称。
         :type SecretName: str
         :param VersionId: 指定对应凭据的版本号。
+对于云产品凭据如Mysql凭据，通过指定凭据名称和历史版本号来获取历史轮转凭据的明文信息，如果要获取当前正在使用的凭据版本的明文，需要将版本号指定为：SSM_Current。
         :type VersionId: str
         """
         self.SecretName = None
@@ -437,9 +778,11 @@ class GetSecretValueResponse(AbstractModel):
         :type SecretName: str
         :param VersionId: 该凭据对应的版本号。
         :type VersionId: str
-        :param SecretBinary: 在创建凭据(CreateSecret)时，如果指定的是二进制数据，则该字段为返回结果，并且使用base64进行编码，应用方需要进行base64解码后获取原始数据。SecretBinary和SecretString只有一个不为空。
+        :param SecretBinary: 在创建凭据(CreateSecret)时，如果指定的是二进制数据，则该字段为返回结果，并且使用base64进行编码，应用方需要进行base64解码后获取原始数据。
+SecretBinary和SecretString只有一个不为空。
         :type SecretBinary: str
-        :param SecretString: 在创建凭据(CreateSecret)时，如果指定的是普通文本数据，则该字段为返回结果。SecretBinary和SecretString只有一个不为空。
+        :param SecretString: 在创建凭据(CreateSecret)时，如果指定的是普通文本数据，则该字段为返回结果。
+SecretBinary和SecretString只有一个不为空。
         :type SecretString: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
@@ -558,12 +901,23 @@ class ListSecretsRequest(AbstractModel):
         :type Limit: int
         :param OrderType: 根据创建时间的排序方式，0或者不设置则使用降序排序， 1 表示升序排序。
         :type OrderType: int
-        :param State: 根据凭据状态进行过滤，默认为0表示查询全部，1 表示查询Enabed 凭据列表，2表示查询Disabled 凭据列表， 3 表示查询PendingDelete 凭据列表。
+        :param State: 根据凭据状态进行过滤。
+默认为0表示查询全部。
+1 --  表示查询Enabled 凭据列表。
+2 --  表示查询Disabled 凭据列表。
+3 --  表示查询PendingDelete 凭据列表。
+4 --  表示PendingCreate。
+5 --  表示CreateFailed。
+其中状态PendingCreate和CreateFailed只有在SecretType为云产品凭据时生效
         :type State: int
         :param SearchSecretName: 根据凭据名称进行过滤，为空表示不过滤。
         :type SearchSecretName: str
-        :param TagFilters: 标签过滤条件
+        :param TagFilters: 标签过滤条件。
         :type TagFilters: list of TagFilter
+        :param SecretType: 0  -- 表示用户自定义凭据，默认为0。
+1  -- 表示用户云产品凭据。
+这个参数只能在云产品凭据(1)和用户自定义凭据(0)中二选一。
+        :type SecretType: int
         """
         self.Offset = None
         self.Limit = None
@@ -571,6 +925,7 @@ class ListSecretsRequest(AbstractModel):
         self.State = None
         self.SearchSecretName = None
         self.TagFilters = None
+        self.SecretType = None
 
 
     def _deserialize(self, params):
@@ -585,6 +940,7 @@ class ListSecretsRequest(AbstractModel):
                 obj = TagFilter()
                 obj._deserialize(item)
                 self.TagFilters.append(obj)
+        self.SecretType = params.get("SecretType")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -624,6 +980,71 @@ class ListSecretsResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class ProductPrivilegeUnit(AbstractModel):
+    """凭据关联产品时被赋予的权限
+
+    """
+
+    def __init__(self):
+        """
+        :param PrivilegeName: 权限名称，当前可选：
+GlobalPrivileges
+DatabasePrivileges
+TablePrivileges
+ColumnPrivileges
+
+当权限为DatabasePrivileges时，必须通过参数Database指定数据库名；
+
+当权限为TablePrivileges时，必须通过参数Database和TableName指定数据库名以及数据库中的表名；
+
+当权限为ColumnPrivileges时，必须通过参数Database、TableName和CoulmnName指定数据库、数据库中的表名以及表中的列名。
+        :type PrivilegeName: str
+        :param Privileges: 权限列表。
+对于Mysql产品来说，可选权限值为：
+
+1. GlobalPrivileges 中权限的可选值为："SELECT","INSERT","UPDATE","DELETE","CREATE", "PROCESS", "DROP","REFERENCES","INDEX","ALTER","SHOW DATABASES","CREATE TEMPORARY TABLES","LOCK TABLES","EXECUTE","CREATE VIEW","SHOW VIEW","CREATE ROUTINE","ALTER ROUTINE","EVENT","TRIGGER"。
+注意，不传该参数表示清除该权限。
+
+2. DatabasePrivileges 权限的可选值为："SELECT","INSERT","UPDATE","DELETE","CREATE", "DROP","REFERENCES","INDEX","ALTER","CREATE TEMPORARY TABLES","LOCK TABLES","EXECUTE","CREATE VIEW","SHOW VIEW","CREATE ROUTINE","ALTER ROUTINE","EVENT","TRIGGER"。
+注意，不传该参数表示清除该权限。
+
+3. TablePrivileges 权限的可选值为：权限的可选值为："SELECT","INSERT","UPDATE","DELETE","CREATE", "DROP","REFERENCES","INDEX","ALTER","CREATE VIEW","SHOW VIEW", "TRIGGER"。
+注意，不传该参数表示清除该权限。
+
+4. ColumnPrivileges 权限的可选值为："SELECT","INSERT","UPDATE","REFERENCES"。
+注意，不传该参数表示清除该权限。
+        :type Privileges: list of str
+        :param Database: 仅当PrivilegeName为DatabasePrivileges时这个值才有效。
+        :type Database: str
+        :param TableName: 仅当PrivilegeName为TablePrivileges时这个值才有效，并且此时需要填充Database显式指明所在的数据库实例。
+        :type TableName: str
+        :param ColumnName: 仅当PrivilegeName为ColumnPrivileges时这个值才生效，并且此时必须填充：
+Database - 显式指明所在的数据库实例。
+TableName - 显式指明所在表
+        :type ColumnName: str
+        """
+        self.PrivilegeName = None
+        self.Privileges = None
+        self.Database = None
+        self.TableName = None
+        self.ColumnName = None
+
+
+    def _deserialize(self, params):
+        self.PrivilegeName = params.get("PrivilegeName")
+        self.Privileges = params.get("Privileges")
+        self.Database = params.get("Database")
+        self.TableName = params.get("TableName")
+        self.ColumnName = params.get("ColumnName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class PutSecretValueRequest(AbstractModel):
     """PutSecretValue请求参数结构体
 
@@ -635,7 +1056,8 @@ class PutSecretValueRequest(AbstractModel):
         :type SecretName: str
         :param VersionId: 指定新增加的版本号，最长64 字节，使用字母、数字或者 - _ . 的组合并且以字母或数字开头。
         :type VersionId: str
-        :param SecretBinary: 二进制凭据信息，使用base64编码。SecretBinary 和 SecretString 必须且只能设置一个。
+        :param SecretBinary: 二进制凭据信息，使用base64编码。
+SecretBinary 和 SecretString 必须且只能设置一个。
         :type SecretBinary: str
         :param SecretString: 文本类型凭据信息明文（不需要进行base64编码），SecretBinary 和 SecretString 必须且只能设置一个。
         :type SecretString: str
@@ -730,6 +1152,51 @@ class RestoreSecretResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class RotateProductSecretRequest(AbstractModel):
+    """RotateProductSecret请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param SecretName: 需要轮转的凭据名。
+        :type SecretName: str
+        """
+        self.SecretName = None
+
+
+    def _deserialize(self, params):
+        self.SecretName = params.get("SecretName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class RotateProductSecretResponse(AbstractModel):
+    """RotateProductSecret返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param FlowID: 轮转异步任务ID号。
+        :type FlowID: int
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.FlowID = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.FlowID = params.get("FlowID")
+        self.RequestId = params.get("RequestId")
+
+
 class SecretMetadata(AbstractModel):
     """凭据的基础信息
 
@@ -737,22 +1204,34 @@ class SecretMetadata(AbstractModel):
 
     def __init__(self):
         """
-        :param SecretName: 凭据名称。
+        :param SecretName: 凭据名称
         :type SecretName: str
-        :param Description: 凭据的描述信息。
+        :param Description: 凭据的描述信息
         :type Description: str
-        :param KmsKeyId: 用于加密凭据的KMS KeyId。
+        :param KmsKeyId: 用于加密凭据的KMS KeyId
         :type KmsKeyId: str
-        :param CreateUin: 创建者UIN。
+        :param CreateUin: 创建者UIN
         :type CreateUin: int
-        :param Status: 凭据状态：Enabled、Disabled、PendingDelete
+        :param Status: 凭据状态：Enabled、Disabled、PendingDelete、Creating、Failed
         :type Status: str
-        :param DeleteTime: 凭据删除日期，对于status为PendingDelete 的有效，unix时间戳。
+        :param DeleteTime: 凭据删除日期，对于status为PendingDelete 的有效，unix时间戳
         :type DeleteTime: int
-        :param CreateTime: 凭据创建时间，unix时间戳。
+        :param CreateTime: 凭据创建时间，unix时间戳
         :type CreateTime: int
-        :param KmsKeyType: 用于加密凭据的KMS CMK类型，DEFAULT 表示SecretsManager 创建的默认密钥， CUSTOMER 表示用户指定的密钥。
+        :param KmsKeyType: 用于加密凭据的KMS CMK类型，DEFAULT 表示SecretsManager 创建的默认密钥， CUSTOMER 表示用户指定的密钥
         :type KmsKeyType: str
+        :param RotationStatus: 1:--开启轮转；0--禁止轮转
+注意：此字段可能返回 null，表示取不到有效值。
+        :type RotationStatus: int
+        :param NextRotationTime: 下一次轮转开始时间，uinx 时间戳
+注意：此字段可能返回 null，表示取不到有效值。
+        :type NextRotationTime: int
+        :param SecretType: 0 -- 用户自定义凭据；1 -- 云产品凭据
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SecretType: int
+        :param ProductName: 云产品名称，仅在SecretType为1，即凭据类型为云产品凭据时生效
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ProductName: str
         """
         self.SecretName = None
         self.Description = None
@@ -762,6 +1241,10 @@ class SecretMetadata(AbstractModel):
         self.DeleteTime = None
         self.CreateTime = None
         self.KmsKeyType = None
+        self.RotationStatus = None
+        self.NextRotationTime = None
+        self.SecretType = None
+        self.ProductName = None
 
 
     def _deserialize(self, params):
@@ -773,6 +1256,10 @@ class SecretMetadata(AbstractModel):
         self.DeleteTime = params.get("DeleteTime")
         self.CreateTime = params.get("CreateTime")
         self.KmsKeyType = params.get("KmsKeyType")
+        self.RotationStatus = params.get("RotationStatus")
+        self.NextRotationTime = params.get("NextRotationTime")
+        self.SecretType = params.get("SecretType")
+        self.ProductName = params.get("ProductName")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -887,6 +1374,62 @@ class UpdateDescriptionResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class UpdateRotationStatusRequest(AbstractModel):
+    """UpdateRotationStatus请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param SecretName: 云产品凭据名称。
+        :type SecretName: str
+        :param EnableRotation: 是否开启轮转。
+True -- 开启轮转；
+False -- 禁止轮转。
+        :type EnableRotation: bool
+        :param Frequency: 轮转周期，以天为单位，最小为30天，最大为365天。
+        :type Frequency: int
+        :param RotationBeginTime: 用户设置的期望开始轮转时间，格式为：2006-01-02 15:04:05。
+当EnableRotation为True时，如果不填RotationBeginTime，则默认填充为当前时间。
+        :type RotationBeginTime: str
+        """
+        self.SecretName = None
+        self.EnableRotation = None
+        self.Frequency = None
+        self.RotationBeginTime = None
+
+
+    def _deserialize(self, params):
+        self.SecretName = params.get("SecretName")
+        self.EnableRotation = params.get("EnableRotation")
+        self.Frequency = params.get("Frequency")
+        self.RotationBeginTime = params.get("RotationBeginTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class UpdateRotationStatusResponse(AbstractModel):
+    """UpdateRotationStatus返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class UpdateSecretRequest(AbstractModel):
     """UpdateSecret请求参数结构体
 
@@ -898,9 +1441,10 @@ class UpdateSecretRequest(AbstractModel):
         :type SecretName: str
         :param VersionId: 指定需要更新凭据内容的版本号。
         :type VersionId: str
-        :param SecretBinary: 新的凭据内容为二进制的场景使用该字段，并使用base64进行编码。SecretBinary 和 SecretString 只能一个不为空。
+        :param SecretBinary: 新的凭据内容为二进制的场景使用该字段，并使用base64进行编码。
+SecretBinary 和 SecretString 只能一个不为空。
         :type SecretBinary: str
-        :param SecretString: 新的凭据内容为文本的场景使用该字段，不需要base64编码。SecretBinary 和 SecretString 只能一个不为空。
+        :param SecretString: 新的凭据内容为文本的场景使用该字段，不需要base64编码SecretBinary 和 SecretString 只能一个不为空。
         :type SecretString: str
         """
         self.SecretName = None
